@@ -1,11 +1,11 @@
 
 # Imports
+import stouputils as stp
 from .loading import main as loading_main
 from .custom_blocks import main as custom_blocks_main
 from .loot_tables import main as loot_tables_main
-from ..utils.print import *
 
-@measure_time(info, "Datapack successfully generated")
+@stp.measure_time(stp.info, "Datapack successfully generated")
 def main(config: dict):
 	print()
 
